@@ -14,7 +14,7 @@
 
 """Stream data from/to Nuclio into pandas DataFrame"""
 
-__version__ = '0.10.4'
+__version__ = '0.10.5'
 
 import json
 import pandas as pd
@@ -121,5 +121,25 @@ def session_from_env():
     if data is None:
         return Session()
 
-    obj = json.loads(data)
+    if data.startswith("{"):
+        obj = json.loads(data)
+    else:
+        obj = {}
+        pairs = data.split(",")
+        for pair in pairs:
+            pair = pair.split("=")
+            if len(pair) != 2:
+                continue
+            obj[pair[0]] = pair[1]
+
+    v3io_api = environ.get("V3IO_API")
+    if v3io_api:
+        obj["url"] = v3io_api
+
+    token = environ.get("V3IO_ACCESS_KEY")
+    if token:
+        obj["token"] = token
+        # If token was provided, we don't need user
+        obj.pop("user", None)
+
     return Session(**obj)
